require 'acceptance_helpers'

resource 'Object Type' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Object Types are the types of the objects."

  before { 12.times { create(:mime_type) } }

  let(:object_types) { ObjectType.all }
  let(:mimetypes) { MimeType.all }

  get '/v1/object_types' do

    example_request 'Get a list of object types' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(status).to eq(200)
    end
  end

  get '/v1/object_types/:id' do
    let(:id) { object_types.first.id }

    example 'Get an object type' do
      do_request
      expect(path).to eq("/v1/object_types/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(ObjectType.find(id)))
      expect(status).to eq(200)
    end
  end

  post '/v1/object_types' do
    include_context "authenticate_user_admin"

    parameter :name, 'The name of the object type', scope: :object_type
    parameter :mime_types, 'Array of mime_types', scope: :object_type

    let(:name) { Faker::Lorem.word }
    let(:mime_types) { [ { "id": mimetypes.first.id } ] }
    let(:raw_post) { params.to_json }

    example 'Adding an object_type' do
      do_request
      expect(status).to eq(201)
    end
  end


  delete 'v1/object_types/:id' do
    include_context "authenticate_user_admin"

    parameter :id, "The id of the object_type"

    let(:id) { object_types.first.id }

    example 'Destroying an object_type' do
      do_request
      expect(status).to eq(200)
    end
  end

  put '/v1/object_types/:id' do
    include_context "authenticate_user_admin"

    parameter :id, "The id of the object_type"
    parameter :name, 'The name of the object type', scope: :object_type
    parameter :mime_types, 'Array of mime_types', scope: :object_type


    let(:id) { object_types.first.id }
    let(:name) { Faker::Lorem.word }
    let(:mime_types) { [ { "id": mimetypes.first.id } ] }
    let(:raw_post) { params.to_json }

    example 'Updating an object_type' do
      do_request
      expect(status).to eq(200)
    end
  end

end
